@@ -6,8 +6,7 @@
 #ifdef Q_WS_MAEMO5
 #include <QtMaemo5/QMaemo5InformationBox>
 #endif
-#define NORMAL "normal"
-#define REMOVE "remove"
+
 
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindow)
@@ -297,12 +296,6 @@ void MainWindow::on_searchLineEdit_returnPressed()
 
 void MainWindow::removePlaylistsMode()
 {
-    if (articleList->isVisible())
-            articleList->hide();
-    else if (player->isVisible())
-        player->hide();
 
-    this->playlist->show();
-    this->playlist->setMode(REMOVE);
 
 }
