@@ -11,6 +11,7 @@ Playlist::Playlist(QWidget *parent) :
     playlistlist = new Playlists();
     this->updateList();
     ui->treeWidget->setColumnCount(2);
+    ui->treeWidget->setColumnWidth(0,300);
 
 
 
@@ -66,13 +67,25 @@ void Playlist::updateList()
     QList<QTreeWidgetItem *> removes;
     foreach(QString title, this->playlistlist->getPlaylistTitles())
     {
-        QTreeWidgetItem *itemRemove = new QTreeWidgetItem(QStringList("Remove"));
-        itemRemove->setData(1, 1, QVariant(title));
+
         QTreeWidgetItem *item = new QTreeWidgetItem(QStringList(title));
         QList<QTreeWidgetItem*> children;
+
+        QTreeWidgetItem *itemRemove = new QTreeWidgetItem(QStringList("Remove"));
+        itemRemove->setData(1, Qt::DisplayRole, QVariant(title));
+        QList<QTreeWidgetItem*> removeChildren;
+
         foreach (QString article, this->playlistlist->getPlaylistContent(title))
+        {
             children.append(new QTreeWidgetItem(QStringList(article)));
+
+            QTreeWidgetItem *temp = new QTreeWidgetItem(QStringList("Remove"));
+            temp->setData(1,Qt::DisplayRole, QVariant(article));
+            removeChildren.append(temp);
+
+        }
         item->addChildren(children);
+        itemRemove->addChildren(removeChildren);
         items.append(item);
         removes.append(itemRemove);
        // item->set
